# eric7.EricXML.PluginRepositoryReader

Module to read the plug-in repository contents file.

### Global Attributes

None

### Classes

PluginRepositoryReader | Class to read the plug-in repository contents file.

### Functions

None

## PluginRepositoryReader

Class to read the plug-in repository contents file.

### Derived from

XMLStreamReaderBase

### Class Attributes

supportedVersions

### Class Methods

None

### Methods

PluginRepositoryReader | Constructor
__readPlugin | Private method to read the plug-in info.
readXML | Public method to read and parse the XML document.

### Static Methods

None

#### PluginRepositoryReader (Constructor)

PluginRepositoryReader(device, entryCallback)

Constructor

device
  reference to the I/O device to read from (QIODevice)
entryCallback
  reference to a function to be called once the data for a plug-in has been read (function)

#### PluginRepositoryReader.__readPlugin

__readPlugin()

Private method to read the plug-in info.

#### PluginRepositoryReader.readXML

readXML()

Public method to read and parse the XML document.

Up